@@ -14,19 +14,19 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
-#include <libgnomevfs/gnome-vfs.h>
 
 unsigned int
-create_sid_path (const char *path);
+create_sid_path(const char *path);
 
 unsigned int
-sidtune_is_ok (const gchar *path);
+sidtune_is_ok(const gchar *path);
 
 #ifdef HILDON
-unsigned int mmc_ok ();
+unsigned int mmc_ok();
 #endif
 
-unsigned int sidpath_ok ();
+unsigned int sidpath_ok();
+unsigned int thumbpath_ok();
 
 #endif
 
